@@ -1,4 +1,5 @@
-# coding: utf-8
+from __future__ import annotations
+
 import configparser
 from contextlib import contextmanager
 import io
@@ -25,11 +26,9 @@ from ..environment import EnvironmentContext
 from ..migration import MigrationContext
 from ..operations import Operations
 from ..util import sqla_compat
-from ..util.compat import string_types
-from ..util.compat import text_type
 from ..util.sqla_compat import create_mock_engine
 from ..util.sqla_compat import sqla_14
-from ..util.sqla_compat import sqla_1x
+from ..util.sqla_compat import sqla_2
 
 
 testing_config = configparser.ConfigParser()
@@ -37,10 +36,7 @@ testing_config.read(["test.cfg"])
 
 
 class TestBase(SQLAlchemyTestBase):
-    if sqla_1x:
-        is_sqlalchemy_future = False
-    else:
-        is_sqlalchemy_future = True
+    is_sqlalchemy_future = sqla_2
 
     @testing.fixture()
     def ops_context(self, migration_context):
@@ -138,7 +134,6 @@ def op_fixture(
     literal_binds=False,
     native_boolean=None,
 ):
-
     opts = {}
     if naming_convention:
         opts["target_metadata"] = MetaData(naming_convention=naming_convention)
@@ -203,10 +198,10 @@ def op_fixture(
     if not as_sql:
 
         def execute(stmt, *multiparam, **param):
-            if isinstance(stmt, string_types):
+            if isinstance(stmt, str):
                 stmt = text(stmt)
             assert stmt.supports_execution
-            sql = text_type(stmt.compile(dialect=ctx_dialect))
+            sql = str(stmt.compile(dialect=ctx_dialect))
 
             buf.write(sql)
 
@@ -221,7 +216,6 @@ def op_fixture(
 
 
 class AlterColRoundTripFixture:
-
     # since these tests are about syntax, use more recent SQLAlchemy as some of
     # the type / server default compare logic might not work on older
     # SQLAlchemy versions as seems to be the case for SQLAlchemy 1.1 on Oracle
